@@ -1,8 +1,12 @@
 mod addr;
 mod tcp;
 mod unix;
+mod wss;
 
 pub use addr::*;
+pub use wss::*;
+
+#[cfg(not(target_arch = "wasm32"))]
 pub use tcp::*;
 #[cfg(unix)]
 pub use unix::*;
